@@ -6,6 +6,9 @@ use warnings;
 use Carp;
 use base 'Class::Accessor';
 
+use Time::Local;
+use POSIX 'strftime';
+
 use WWW::Mechanize;
 use Finance::Bank::Postbank_de::Account;
 use Encode qw(decode);
@@ -13,7 +16,8 @@ use Mozilla::CA;
 
 use vars qw[ $VERSION ];
 
-$VERSION = '0.40';
+$VERSION = '0.41';
+
 
 BEGIN {
   Finance::Bank::Postbank_de->mk_accessors(qw( agent login password urls ));
@@ -302,6 +306,14 @@ sub get_account_statement {
       return;
   };
   $agent->form_with_fields( 'selectForm:kontoauswahl' );
+  
+  if(my $past_days = $args{past_days}) {
+    my ($day, $month, $year) = split/\./, $agent->current_form->value('umsatzanzeigeGiro:salesForm:umsatzFilterOptionenAufklappbarSuchfeldPanel:accordion:vonBisDatum:datumForm:bisGruppe:bisDatum');
+    my $end_epoch = timegm(0, 0, 0, $day, $month-1, $year);
+    my $from_date = strftime '%d.%m.%Y', localtime($end_epoch-($past_days-1)*60*60*24);
+    $agent->current_form->value('umsatzanzeigeGiro:salesForm:umsatzFilterOptionenAufklappbarSuchfeldPanel:accordion:vonBisDatum:datumForm:vonGruppe:vonDatum' => $from_date);
+  };
+
   if (exists $args{account_number}) {
     $self->log("Getting account statement for $args{account_number}");
     # Load the account numbers if not already loaded
@@ -533,6 +545,9 @@ be retrieved from the agent, but this will most likely change, as the print vers
 of the account statement is not a navigable page. The result of the function
 is either undef or a Finance::Bank::Postbank_de::Account object.
 
+C<past_days> - Number of days in the past to request the statement for
+The default is 10.
+
 =head2 $account->unread_messages
 
 Returns the number of unread messages. There is no way
